@@ -59,9 +59,9 @@ pref("general.warnOnAboutConfig", true);
 pref("browser.bookmarks.max_backups",       5);
 
 pref("browser.cache.disk.enable",           true);
-//@line 63 "/builds/slave/mozilla-central-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 63 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 pref("browser.cache.disk.capacity",         51200);
-//@line 67 "/builds/slave/mozilla-central-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 67 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 pref("browser.cache.memory.enable",         true);
 //pref("browser.cache.memory.capacity",     -1);
 // -1 = determine dynamically, 0 = none, n = memory capacity in kilobytes
@@ -70,7 +70,7 @@ pref("browser.cache.disk_cache_ssl",        false);
 pref("browser.cache.check_doc_frequency",   3);
 
 pref("browser.cache.offline.enable",           true);
-//@line 76 "/builds/slave/mozilla-central-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 76 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 // offline cache capacity in kilobytes
 pref("browser.cache.offline.capacity",         512000);
 
@@ -81,7 +81,7 @@ pref("offline-apps.quota.max",        204800);
 // the user should be warned if offline app disk usage exceeds this amount
 // (in kilobytes)
 pref("offline-apps.quota.warn",        51200);
-//@line 92 "/builds/slave/mozilla-central-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 92 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
 // Fastback caching - if this pref is negative, then we calculate the number
 // of content viewers to cache based on the amount of available memory.
@@ -145,11 +145,11 @@ pref("media.enforce_same_site_origin", false);
 // Media cache size in kilobytes
 pref("media.cache_size", 51200);
 
-//@line 156 "/builds/slave/mozilla-central-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 156 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 pref("media.ogg.enabled", true);
-//@line 159 "/builds/slave/mozilla-central-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 159 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 pref("media.wave.enabled", true);
-//@line 161 "/builds/slave/mozilla-central-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 161 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
 // Whether to autostart a media element with an |autoplay| attribute
 pref("media.autoplay.enabled", true);
@@ -167,10 +167,10 @@ pref("accessibility.warn_on_browsewithcaret", true);
 
 pref("accessibility.browsewithcaret_shortcut.enabled", true);
 
-//@line 192 "/builds/slave/mozilla-central-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 192 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 // Only on mac tabfocus is expected to handle UI widgets as well as web content
 pref("accessibility.tabfocus_applies_to_xul", true);
-//@line 195 "/builds/slave/mozilla-central-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 195 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -514,9 +514,9 @@ pref("dom.storage.enabled", true);
 pref("dom.storage.default_quota",      5120);
 
 // Parsing perf prefs. For now just mimic what the old code did.
-//@line 539 "/builds/slave/mozilla-central-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 539 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 pref("content.sink.pending_event_mode", 0);
-//@line 541 "/builds/slave/mozilla-central-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 541 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
 // Disable popups from plugins by default
 //   0 = openAllowed
@@ -565,9 +565,9 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 590 "/builds/slave/mozilla-central-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 590 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.help", false);
-//@line 592 "/builds/slave/mozilla-central-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 592 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -724,6 +724,8 @@ pref("network.IDN.whitelist.tw", true);
 pref("network.IDN.whitelist.vn", true);
 
 // IDN ccTLDs
+// ae, UAE, .<Emarat>
+pref("network.IDN.whitelist.xn--mgbaam7a8h", true); 
 // sa, Saudi Arabia, .<al-Saudiah>
 pref("network.IDN.whitelist.xn--mgberp4a5d4ar", true); 
 // ru, Russian Federation, .<RF>
@@ -817,7 +819,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 847 "/builds/slave/mozilla-central-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 849 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
 // Controls which NTLM authentication implementation we default to. True forces
 // the use of our generic (internal) NTLM authentication implementation vs. any
@@ -1201,9 +1203,7 @@ pref("dom.max_script_run_time", 10);
 
 // How long a plugin is allowed to process a synchronous IPC message
 // before we consider it "hung".
-//
-//  NB: chosen to match dom.max_script_run_time by default
-pref("dom.ipc.plugins.timeoutSecs", 10);
+pref("dom.ipc.plugins.timeoutSecs", 45);
 
 pref("svg.enabled", true);
 pref("svg.smil.enabled", false);
@@ -1240,18 +1240,18 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1667 "/builds/slave/mozilla-central-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 1667 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 1669 "/builds/slave/mozilla-central-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 1669 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 // Mac specific preference defaults
 pref("browser.drag_out_of_frame_style", 1);
 pref("ui.key.saveLink.shift", false); // true = shift, false = meta
 pref("ui.click_hold_context_menus", false);
 
-//@line 1675 "/builds/slave/mozilla-central-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 1675 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 // whether to always use ATSUI for text even if CoreText is available
 pref("gfx.force_atsui_text", false);
-//@line 1678 "/builds/slave/mozilla-central-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 1678 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
 // default fonts (in UTF8 and using canonical names)
 // to determine canonical font names, use a debug build and 
@@ -1663,21 +1663,21 @@ pref("ui.panel.default_level_parent", false);
 
 pref("mousewheel.system_scroll_override_on_root_content.enabled", false);
 
-//@line 2091 "/builds/slave/mozilla-central-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2091 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2294 "/builds/slave/mozilla-central-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2294 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2390 "/builds/slave/mozilla-central-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2390 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2665 "/builds/slave/mozilla-central-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2665 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2733 "/builds/slave/mozilla-central-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2733 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2759 "/builds/slave/mozilla-central-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2759 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2779 "/builds/slave/mozilla-central-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2779 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2787 "/builds/slave/mozilla-central-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2787 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1714,15 +1714,12 @@ pref("image.cache.timeweight", 500);
 // The default Accept header sent for images loaded over HTTP(S)
 pref("image.http.accept", "image/png,image/*;q=0.8,*/*;q=0.5");
 
-//@line 2829 "/builds/slave/mozilla-central-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2829 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2834 "/builds/slave/mozilla-central-macosx-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2834 "/builds/slave/mozilla-1.9.2-macosx-xulrunner/build/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
 
 // Enable/Disable the orientation API for content
 pref("accelerometer.enabled", true);
-
-// Enable/Disable HTML5 parser
-pref("html5.enable", false);
